==> nextcloud-app-contacts-3.1.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ka_GE.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "კონტაქტები",
    "All contacts" : "ყველა კონტაქტი",
    "Details" : "დეტალები",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "გაუქმება",
    "Groups" : "ჯგუფები",
    "New contact" : "ახალი კონტაქტი",
    "Rename" : "სახელის შეცვლა",
    "Enabled" : "მოქმედია",
    "Disabled" : "არაა მოქმედი",
    "Copy link" : "ბმულის კოპირება",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Import into" : "იმპორტირება",
    "First name" : "სახელი",
    "Last name" : "გვარი",
    "Nickname" : "ნიკნეიმი",
    "Detailed name" : "დეტალური სახელი",
    "Additional names" : "დამატებითი სახელები",
    "Prefix" : "პრეფიქსი",
    "Suffix" : "სუფიქსი",
    "Notes" : "შენიშვნები",
    "Website" : "ვებ-საიტი",
    "Federated Cloud ID" : "ფედერალური ქლაუდ ID",
    "Home" : "სახლი",
    "Work" : "სამსახური",
    "Other" : "სხვა",
    "Address" : "მისამართი",
    "Post office box" : "საფოსტო ყუთი",
    "City" : "ქალაქი",
    "State or province" : "შტატი ან პროვინცია",
    "Postal code" : "საფოსტო კოდი",
    "Country" : "ქვეყანა",
    "Birthday" : "დაბადების დრე",
    "Anniversary" : "დაბადების დღე",
    "Date of death" : "გადრდაცვალების დღე",
    "Email" : "ელ-ფოსტა",
    "Instant messaging" : "მესინჯერი",
    "Phone" : "ტელეფონი",
    "Mobile" : "მობილური",
    "Work mobile" : "სამუშაო ტელეფონი",
    "Fax" : "ფაქსი",
    "Fax home" : "სახლის ფაქსი",
    "Fax work" : "სამსახურის ფაქსი",
    "Pager" : "პეიჯერი",
    "Voice" : "ხმა",
    "Car" : "მაქნანა",
    "Work pager" : "სამუშაო პეიჯერი",
    "Social network" : "სოციალური ქსელი",
    "Relationship" : "ურთიერთობა",
    "Spouse" : "მეუღლე",
    "Child" : "შვილი",
    "Mother" : "დედა",
    "Father" : "მამა",
    "Parent" : "მშობელი",
    "Brother" : "ძმა",
    "Sister" : "და",
    "Relative" : "ნათესავი",
    "Friend" : "მეგობარი",
    "Colleague" : "კოლეგა",
    "Manager" : "მენეჯერი",
    "Assistant" : "ასისტენტი",
    "Gender" : "სქესი",
    "Female" : "მდედორობითი",
    "Male" : "მამრობითი"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-contacts-3.1.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ka_GE.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "კონტაქტები",
    "All contacts" : "ყველა კონტაქტი",
    "Details" : "დეტალები",
    "Loading" : "იტვირთება",
    "Name" : "სახელი",
    "Title" : "სათაური",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "გაუქმება",
    "Groups" : "ჯგუფები",
    "New contact" : "ახალი კონტაქტი",
    "No results" : "შედეგები არაა",
    "Last modified" : "ბოლო ცვლილება",
    "Rename" : "სახელის შეცვლა",
    "Enabled" : "მოქმედია",
    "Disabled" : "არაა მოქმედი",
    "Copy link" : "ბმულის კოპირება",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "can edit" : "შეუძლია შეცვლა",
    "Importing into" : "იმპორტირება",
    "Import into" : "იმპორტირება",
    "Address book name" : "მისამართების წიგნის სახელი",
    "First name" : "სახელი",
    "Last name" : "გვარი",
    "Display name" : "დისპლეი სახელი",
    "Not grouped" : "არაა დაჯგუფებული",
    "Nickname" : "ნიკნეიმი",
    "Detailed name" : "დეტალური სახელი",
    "Additional names" : "დამატებითი სახელები",
    "Prefix" : "პრეფიქსი",
    "Suffix" : "სუფიქსი",
    "Notes" : "შენიშვნები",
    "Website" : "ვებ-საიტი",
    "Location" : "ადგილმდებარეობა",
    "Federated Cloud ID" : "ფედერალური ქლაუდ ID",
    "Home" : "სახლი",
    "Work" : "სამსახური",
    "Other" : "სხვა",
    "Address" : "მისამართი",
    "Post office box" : "საფოსტო ყუთი",
    "City" : "ქალაქი",
    "State or province" : "შტატი ან პროვინცია",
    "Postal code" : "საფოსტო კოდი",
    "Country" : "ქვეყანა",
    "Birthday" : "დაბადების დრე",
    "Anniversary" : "დაბადების დღე",
    "Date of death" : "გადრდაცვალების დღე",
    "Email" : "ელ-ფოსტა",
    "Instant messaging" : "მესინჯერი",
    "Phone" : "ტელეფონი",
    "Mobile" : "მობილური",
    "Work mobile" : "სამუშაო ტელეფონი",
    "Fax" : "ფაქსი",
    "Fax home" : "სახლის ფაქსი",
    "Fax work" : "სამსახურის ფაქსი",
    "Pager" : "პეიჯერი",
    "Voice" : "ხმა",
    "Car" : "მაქნანა",
    "Work pager" : "სამუშაო პეიჯერი",
    "Social network" : "სოციალური ქსელი",
    "Relationship" : "ურთიერთობა",
    "Spouse" : "მეუღლე",
    "Child" : "შვილი",
    "Mother" : "დედა",
    "Father" : "მამა",
    "Parent" : "მშობელი",
    "Brother" : "ძმა",
    "Sister" : "და",
    "Relative" : "ნათესავი",
    "Friend" : "მეგობარი",
    "Colleague" : "კოლეგა",
    "Manager" : "მენეჯერი",
    "Assistant" : "ასისტენტი",
    "Contact" : "კონტაქტი",
    "Gender" : "სქესი",
    "Female" : "მდედორობითი",
    "Male" : "მამრობითი",
    "None" : "არც ერთი",
    "Unknown" : "ამოუცნობი"
},
"nplurals=2; plural=(n!=1);");
